@@ -76,18 +76,18 @@ class ref_frame:
         
 
 class dyn_obj:
-    def __init__(self, obj, pa, euler_type, parent, init_anim):
+    def __init__(self, obj, pa, euler_type, parent, anim):
         
         self.euler_pa = pa
         
         self.quat = R.from_euler(euler_type, pa).as_quat()
         
-        self.non_rot = ref_frame(obj.name+'_non_rot', parent, init_anim)
+        self.non_rot = ref_frame(obj.name+'_non_rot', parent, anim)
         
-        self.pa_axes = ref_frame(obj.name+'_pa', self.non_rot.ob, init_anim)
+        self.pa_axes = ref_frame(obj.name+'_pa', self.non_rot.ob, anim)
         self.pa_axes.static_6DOF(self.quat, None, None, None)
         
-        self.body = ref_frame(obj.name+'_body', self.pa_axes.ob, init_anim)
+        self.body = ref_frame(obj.name+'_body', self.pa_axes.ob, anim)
         
         obj.parent = self.body.ob
         obj.scale = (scale, scale, scale)
@@ -99,13 +99,15 @@ class dyn_obj:
         self.frames = init_anim.frames
         self.scale = init_anim.scale
         
-    def apply_animation(self, x_list, y_list, z_list, quat_list, frames):
+    def apply_animation(self, x_list, y_list, z_list, quat_list):
         
-        self.pa_axes.dynamic_6DOF(quat_list, None, None, None, frames)
-        self.non_rot.dynamic_6DOF(None, x_list, y_list, z_list, frames)
 
-    def apply_streamline(self, staticity, int_x, int_y, int_z, frames, thickness):
+        self.pa_axes.dynamic_6DOF(quat_list, None, None, None, self.frames)
+        self.non_rot.dynamic_6DOF(None, x_list, y_list, z_list, self.frames)
+
+    def apply_streamline(self, staticity, int_x, int_y, int_z, thickness):
         name = self.name+'_streamline'
+        frames = self.frames
         
         int_size = len(int_x)
         int_coords = np.zeros((int_size, 3))
@@ -140,11 +142,11 @@ class dyn_obj:
                 bpy.data.objects[name].data.keyframe_insert(data_path='bevel_factor_end', frame=cur_frame)
 
 class dyn_vec:
-    def __init__(self, obj, name, scale_mag, scale_off, offset):
+    def __init__(self, obj, name, scale_mag, scale_off, offset, anim):
         self.parent = obj
         self.name = name+"_vector"
         
-        self.parent_rf = ref_frame(self.name+"_empty", self.parent, init_anim)
+        self.parent_rf = ref_frame(self.name+"_empty", self.parent, anim)
 
         self.filepath = self.filepath = __file__.replace("__init__.py", "").replace("\\core.py", "")+'\\assets\\objects\\arrow.obj' #"C:/Users/vargh/Documents/GitHub/bpsci/bpsci/assets/objects/arrow.obj" #bpsci.__file__.replace("__init__.py", "")+'\\assets\\objects\\arrow.obj'
 
@@ -159,7 +161,10 @@ class dyn_vec:
         self.scale = scale_mag
         vec.scale = (scale_mag, scale_off, scale_off)
         
-    def animate(self, x, y, z, frames):
+        self.frames = anim.frames
+    def animate(self, x, y, z):
+        frames = self.frames
+
         max_x = 1
         max_y = 1
         max_z = 1
@@ -175,7 +180,7 @@ class dyn_vec:
         norm_y = y/max_y *self.scale
         norm_z = z/max_z *self.scale
         
-        self.point_rf = ref_frame(self.name+"_pointing_empty", self.parent)
+        self.point_rf = ref_frame(self.name+"_pointing_empty", self.parent, anim)
         
         tracking_constraint = self.parent_rf.ob.constraints.new('DAMPED_TRACK')
         tracking_constraint.target = self.point_rf.ob
